@@ -20,7 +20,7 @@
 
     */
 
-#include "core.h"
+#include "common.h"
 #include "debug.h"
 #include <iostream>
 #include <fstream>
@@ -91,7 +91,7 @@ public:
 	vector<string>* getProperty(const string& name);
 };
 
-};
+}
 
 // TraderQuery
 //----------------------------------------------------------------------------
@@ -221,7 +221,7 @@ void TraderHelper::addDirectory(const string& directory, const string& iface,
 		string currentEntry = directory + "/" + de->d_name;
 
 		string currentIface = iface;
-		if(iface != "") currentIface += "::";
+		if(!iface.empty()) currentIface += "::";
 		currentIface += de->d_name;
 
 		struct stat st;
@@ -334,7 +334,7 @@ public:
 
 static TraderShutdown traderShutdown;
 
-};
+}
 
 // Dispatcher function for reloading the trader data:
 void Dispatcher::reloadTraderData()
